import { DefaultThemeRenderContext } from "./DefaultThemeRenderContext";
import { Element } from "../../../utils/jsx";
import { PageEvent } from "../../events";
import { ContainerReflection, DeclarationHierarchy, DeclarationReflection, ProjectReflection, ReferenceReflection, Reflection, ReflectionGroup, SignatureReflection, Type, TypeParameterContainer } from "../../../models";
import { NavigationItem } from "../../models/NavigationItem";
export declare type ThemePartial<T> = (context: DefaultThemeRenderContext, props: T) => Element | undefined;
export declare type ThemePartialRequired<T> = (context: DefaultThemeRenderContext, props: T) => Element;
export interface DefaultThemePartials {
    reflectionTemplate: ThemePartialRequired<PageEvent<ContainerReflection>>;
    indexTemplate: ThemePartialRequired<PageEvent<ProjectReflection>>;
    defaultLayout: ThemePartialRequired<PageEvent<Reflection>>;
    analytics: ThemePartial<PageEvent<Reflection>>;
    breadcrumb: ThemePartial<Reflection>;
    comment: ThemePartial<Reflection>;
    footer: ThemePartial<PageEvent<Reflection>>;
    header: ThemePartial<PageEvent<Reflection>>;
    hierarchy: ThemePartial<DeclarationHierarchy>;
    index: ThemePartial<ContainerReflection>;
    member: ThemePartial<DeclarationReflection>;
    memberDeclaration: ThemePartial<DeclarationReflection>;
    memberGetterSetter: ThemePartial<DeclarationReflection>;
    memberReference: ThemePartial<ReferenceReflection>;
    memberSignatureBody: (context: DefaultThemeRenderContext, props: SignatureReflection, options?: {
        hideSources?: boolean;
    }) => Element;
    memberSignatureTitle: (context: DefaultThemeRenderContext, props: SignatureReflection, options?: {
        hideName?: boolean;
        arrowStyle?: boolean;
    }) => Element;
    memberSignatures: ThemePartial<DeclarationReflection>;
    memberSources: ThemePartial<DeclarationReflection | SignatureReflection>;
    members: ThemePartial<ContainerReflection>;
    membersGroup: ThemePartial<ReflectionGroup>;
    navigation: ThemePartial<NavigationItem>;
    parameter: ThemePartial<DeclarationReflection>;
    toc: ThemePartial<NavigationItem>;
    tocRoot: ThemePartial<NavigationItem>;
    type: ThemePartial<Type | undefined>;
    typeAndParent: ThemePartial<Type>;
    typeParameters: ThemePartial<TypeParameterContainer>;
}
export declare const defaultThemePartials: DefaultThemePartials;
