"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Application = exports.registerComponent = void 0;
/**
 * List of all known components.
 */
const components = [];
/**
 * Register a new component.
 */
function registerComponent(constructor, selector) {
    components.push({
        selector: selector,
        constructor: constructor,
    });
}
exports.registerComponent = registerComponent;
/**
 * TypeDoc application class.
 */
class Application {
    /**
     * Create a new Application instance.
     */
    constructor() {
        this.createComponents(document.body);
    }
    /**
     * Create all components beneath the given jQuery element.
     */
    createComponents(context) {
        components.forEach((c) => {
            context.querySelectorAll(c.selector).forEach((el) => {
                if (!el.dataset["hasInstance"]) {
                    new c.constructor({ el: el });
                    el.dataset["hasInstance"] = String(true);
                }
            });
        });
    }
}
exports.Application = Application;
