"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Filter = void 0;
const Component_1 = require("../Component");
const pointer_1 = require("../utils/pointer");
class FilterItem {
    constructor(key, value) {
        this.key = key;
        this.value = value;
        this.defaultValue = value;
        this.initialize();
        if (window.localStorage[this.key]) {
            this.setValue(this.fromLocalStorage(window.localStorage[this.key]));
        }
    }
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    initialize() { }
    setValue(value) {
        if (this.value == value)
            return;
        const oldValue = this.value;
        this.value = value;
        window.localStorage[this.key] = this.toLocalStorage(value);
        this.handleValueChange(oldValue, value);
    }
}
class FilterItemCheckbox extends FilterItem {
    initialize() {
        const checkbox = document.querySelector("#tsd-filter-" + this.key);
        if (!checkbox)
            return;
        this.checkbox = checkbox;
        this.checkbox.addEventListener("change", () => {
            this.setValue(this.checkbox.checked);
        });
    }
    handleValueChange(_oldValue, _newValue) {
        if (!this.checkbox)
            return;
        this.checkbox.checked = this.value;
        document.documentElement.classList.toggle("toggle-" + this.key, this.value != this.defaultValue);
    }
    fromLocalStorage(value) {
        return value == "true";
    }
    toLocalStorage(value) {
        return value ? "true" : "false";
    }
}
class FilterItemSelect extends FilterItem {
    initialize() {
        document.documentElement.classList.add("toggle-" + this.key + this.value);
        const select = document.querySelector("#tsd-filter-" + this.key);
        if (!select)
            return;
        this.select = select;
        const onActivate = () => {
            this.select.classList.add("active");
        };
        const onDeactivate = () => {
            this.select.classList.remove("active");
        };
        this.select.addEventListener(pointer_1.pointerDown, onActivate);
        this.select.addEventListener("mouseover", onActivate);
        this.select.addEventListener("mouseleave", onDeactivate);
        this.select.querySelectorAll("li").forEach((el) => {
            el.addEventListener(pointer_1.pointerUp, (e) => {
                select.classList.remove("active");
                this.setValue(e.target.dataset["value"] || "");
            });
        });
        document.addEventListener(pointer_1.pointerDown, (e) => {
            if (this.select.contains(e.target))
                return;
            this.select.classList.remove("active");
        });
    }
    handleValueChange(oldValue, newValue) {
        this.select.querySelectorAll("li.selected").forEach((el) => {
            el.classList.remove("selected");
        });
        const selected = this.select.querySelector('li[data-value="' + newValue + '"]');
        const label = this.select.querySelector(".tsd-select-label");
        if (selected && label) {
            selected.classList.add("selected");
            label.textContent = selected.textContent;
        }
        document.documentElement.classList.remove("toggle-" + oldValue);
        document.documentElement.classList.add("toggle-" + newValue);
    }
    fromLocalStorage(value) {
        return value;
    }
    toLocalStorage(value) {
        return value;
    }
}
class Filter extends Component_1.Component {
    constructor(options) {
        super(options);
        this.optionVisibility = new FilterItemSelect("visibility", "private");
        this.optionInherited = new FilterItemCheckbox("inherited", true);
        this.optionExternals = new FilterItemCheckbox("externals", true);
    }
    static isSupported() {
        try {
            return typeof window.localStorage != "undefined";
        }
        catch (e) {
            return false;
        }
    }
}
exports.Filter = Filter;
