"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Toggle = void 0;
const Component_1 = require("../Component");
const pointer_1 = require("../utils/pointer");
class Toggle extends Component_1.Component {
    constructor(options) {
        super(options);
        this.className = this.el.dataset["toggle"] || "";
        this.el.addEventListener(pointer_1.pointerUp, (e) => this.onPointerUp(e));
        this.el.addEventListener("click", (e) => e.preventDefault());
        document.addEventListener(pointer_1.pointerDown, (e) => this.onDocumentPointerDown(e));
        document.addEventListener(pointer_1.pointerUp, (e) => this.onDocumentPointerUp(e));
    }
    setActive(value) {
        if (this.active == value)
            return;
        this.active = value;
        document.documentElement.classList.toggle("has-" + this.className, value);
        this.el.classList.toggle("active", value);
        const transition = (this.active ? "to-has-" : "from-has-") + this.className;
        document.documentElement.classList.add(transition);
        setTimeout(() => document.documentElement.classList.remove(transition), 500);
    }
    onPointerUp(event) {
        if (pointer_1.hasPointerMoved)
            return;
        this.setActive(true);
        event.preventDefault();
    }
    onDocumentPointerDown(e) {
        if (this.active) {
            if (e.target.closest(".col-menu, .tsd-filter-group")) {
                return;
            }
            this.setActive(false);
        }
    }
    onDocumentPointerUp(e) {
        if (pointer_1.hasPointerMoved)
            return;
        if (this.active) {
            if (e.target.closest(".col-menu")) {
                const link = e.target.closest("a");
                if (link) {
                    let href = window.location.href;
                    if (href.indexOf("#") != -1) {
                        href = href.substr(0, href.indexOf("#"));
                    }
                    if (link.href.substr(0, href.length) == href) {
                        setTimeout(() => this.setActive(false), 250);
                    }
                }
            }
        }
    }
}
exports.Toggle = Toggle;
