import { EventTarget } from "../EventTarget";
/**
 * A global service that monitors the window size and scroll position.
 */
export declare class Viewport extends EventTarget {
    static readonly instance: Viewport;
    /**
     * The current scroll position.
     */
    scrollTop: number;
    /**
     * The previous scrollTop.
     */
    lastY: number;
    /**
     * The width of the window.
     */
    width: number;
    /**
     * The height of the window.
     */
    height: number;
    /**
     * The toolbar (contains the search input).
     */
    toolbar: HTMLDivElement;
    /**
     * Boolean indicating whether the toolbar is shown.
     */
    showToolbar: boolean;
    /**
     * The sticky side nav that contains members of the current page.
     */
    secondaryNav: HTMLElement;
    /**
     * Create new Viewport instance.
     */
    constructor();
    /**
     * Trigger a resize event.
     */
    triggerResize(): void;
    /**
     * Triggered when the size of the window has changed.
     */
    onResize(): void;
    /**
     * Triggered when the user scrolled the viewport.
     */
    onScroll(): void;
    /**
     * Handle hiding/showing of the toolbar.
     */
    hideShowToolbar(): void;
}
