"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Viewport = void 0;
const EventTarget_1 = require("../EventTarget");
const trottle_1 = require("../utils/trottle");
/**
 * A global service that monitors the window size and scroll position.
 */
class Viewport extends EventTarget_1.EventTarget {
    /**
     * Create new Viewport instance.
     */
    constructor() {
        super();
        /**
         * The current scroll position.
         */
        this.scrollTop = 0;
        /**
         * The previous scrollTop.
         */
        this.lastY = 0;
        /**
         * The width of the window.
         */
        this.width = 0;
        /**
         * The height of the window.
         */
        this.height = 0;
        /**
         * Boolean indicating whether the toolbar is shown.
         */
        this.showToolbar = true;
        this.toolbar = (document.querySelector(".tsd-page-toolbar"));
        this.secondaryNav = (document.querySelector(".tsd-navigation.secondary"));
        window.addEventListener("scroll", trottle_1.throttle(() => this.onScroll(), 10));
        window.addEventListener("resize", trottle_1.throttle(() => this.onResize(), 10));
        this.onResize();
        this.onScroll();
    }
    /**
     * Trigger a resize event.
     */
    triggerResize() {
        const event = new CustomEvent("resize", {
            detail: {
                width: this.width,
                height: this.height,
            },
        });
        this.dispatchEvent(event);
    }
    /**
     * Triggered when the size of the window has changed.
     */
    onResize() {
        this.width = window.innerWidth || 0;
        this.height = window.innerHeight || 0;
        const event = new CustomEvent("resize", {
            detail: {
                width: this.width,
                height: this.height,
            },
        });
        this.dispatchEvent(event);
    }
    /**
     * Triggered when the user scrolled the viewport.
     */
    onScroll() {
        this.scrollTop = window.scrollY || 0;
        const event = new CustomEvent("scroll", {
            detail: {
                scrollTop: this.scrollTop,
            },
        });
        this.dispatchEvent(event);
        this.hideShowToolbar();
    }
    /**
     * Handle hiding/showing of the toolbar.
     */
    hideShowToolbar() {
        const isShown = this.showToolbar;
        this.showToolbar = this.lastY >= this.scrollTop || this.scrollTop <= 0;
        if (isShown !== this.showToolbar) {
            this.toolbar.classList.toggle("tsd-page-toolbar--hide");
            this.secondaryNav.classList.toggle("tsd-navigation--toolbar-hide");
        }
        this.lastY = this.scrollTop;
    }
}
exports.Viewport = Viewport;
Viewport.instance = new Viewport();
