"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isMobile = exports.hasPointerMoved = exports.isPointerTouch = exports.isPointerDown = exports.preventNextClick = exports.pointerDownPosition = exports.pointerUp = exports.pointerMove = exports.pointerDown = void 0;
/**
 * Event name of the pointer down event.
 */
exports.pointerDown = "mousedown";
/**
 * Event name of the pointer move event.
 */
exports.pointerMove = "mousemove";
/**
 * Event name of the pointer up event.
 */
exports.pointerUp = "mouseup";
/**
 * Position the pointer was pressed at.
 */
exports.pointerDownPosition = { x: 0, y: 0 };
/**
 * Should the next click on the document be supressed?
 */
exports.preventNextClick = false;
/**
 * Is the pointer down?
 */
exports.isPointerDown = false;
/**
 * Is the pointer a touch point?
 */
exports.isPointerTouch = false;
/**
 * Did the pointer move since the last down event?
 */
exports.hasPointerMoved = false;
/**
 * Is the user agent a mobile agent?
 */
exports.isMobile = /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);
document.documentElement.classList.add(exports.isMobile ? "is-mobile" : "not-mobile");
if (exports.isMobile && "ontouchstart" in document.documentElement) {
    exports.isPointerTouch = true;
    exports.pointerDown = "touchstart";
    exports.pointerMove = "touchmove";
    exports.pointerUp = "touchend";
}
document.addEventListener(exports.pointerDown, (e) => {
    exports.isPointerDown = true;
    exports.hasPointerMoved = false;
    const t = exports.pointerDown == "touchstart"
        ? e.targetTouches[0]
        : e;
    exports.pointerDownPosition.y = t.pageY || 0;
    exports.pointerDownPosition.x = t.pageX || 0;
});
document.addEventListener(exports.pointerMove, (e) => {
    if (!exports.isPointerDown)
        return;
    if (!exports.hasPointerMoved) {
        const t = exports.pointerDown == "touchstart"
            ? e.targetTouches[0]
            : e;
        const x = exports.pointerDownPosition.x - (t.pageX || 0);
        const y = exports.pointerDownPosition.y - (t.pageY || 0);
        exports.hasPointerMoved = Math.sqrt(x * x + y * y) > 10;
    }
});
document.addEventListener(exports.pointerUp, () => {
    exports.isPointerDown = false;
});
document.addEventListener("click", (e) => {
    if (exports.preventNextClick) {
        e.preventDefault();
        e.stopImmediatePropagation();
        exports.preventNextClick = false;
    }
});
