import { DefaultTheme } from "../default/DefaultTheme";
import type { Renderer } from "../../renderer";
import { UrlMapping } from "../../models/UrlMapping";
import { Reflection, ProjectReflection } from "../../../models/reflections/index";
import { PageEvent } from "../../events";
import { NavigationItem } from "../../models/NavigationItem";
import { DefaultThemeRenderContext } from "../default/DefaultThemeRenderContext";
export declare class MinimalTheme extends DefaultTheme {
    /**
     * Create a new DefaultTheme instance.
     *
     * @param renderer  The renderer this theme is attached to.
     */
    constructor(renderer: Renderer);
    getRenderContext(_pageEvent: PageEvent<any>): DefaultThemeRenderContext;
    /**
     * Map the models of the given project to the desired output files.
     *
     * @param project  The project whose urls should be generated.
     * @returns        A list of {@link UrlMapping} instances defining which models
     *                 should be rendered to which files.
     */
    getUrls(project: ProjectReflection): UrlMapping[];
    /**
     * Triggered before a document will be rendered.
     *
     * @param page  An event object describing the current render operation.
     */
    private onRendererBeginPage;
    /**
     * Create a toc navigation item structure.
     *
     * @param model   The models whose children should be written to the toc.
     * @param parent  The parent {@link Models.NavigationItem} the toc should be appended to.
     */
    static buildToc(model: Reflection, parent: NavigationItem): void;
}
export declare class MinimalThemeRendererContext extends DefaultThemeRenderContext {
    indexTemplate: DefaultThemeRenderContext["indexTemplate"];
    defaultLayout: DefaultThemeRenderContext["defaultLayout"];
    header: DefaultThemeRenderContext["header"];
    member: DefaultThemeRenderContext["member"];
}
