"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MinimalThemeRendererContext = exports.MinimalTheme = void 0;
const DefaultTheme_1 = require("../default/DefaultTheme");
const UrlMapping_1 = require("../../models/UrlMapping");
const index_1 = require("../../../models/reflections/index");
const events_1 = require("../../events");
const NavigationItem_1 = require("../../models/NavigationItem");
const templates_1 = require("./templates");
const default_1 = require("./layouts/default");
const DefaultThemeRenderContext_1 = require("../default/DefaultThemeRenderContext");
const header_1 = require("./partials/header");
const member_1 = require("./partials/member");
class MinimalTheme extends DefaultTheme_1.DefaultTheme {
    /**
     * Create a new DefaultTheme instance.
     *
     * @param renderer  The renderer this theme is attached to.
     */
    constructor(renderer) {
        super(renderer);
        renderer.removeComponent("assets");
        renderer.removeComponent("javascript-index");
        renderer.removeComponent("navigation");
        renderer.removeComponent("toc");
        this.listenTo(renderer, events_1.PageEvent.BEGIN, this.onRendererBeginPage);
    }
    getRenderContext(_pageEvent) {
        var _a;
        (_a = this._renderContext) !== null && _a !== void 0 ? _a : (this._renderContext = new MinimalThemeRendererContext(this._markedPlugin));
        return this._renderContext;
    }
    /**
     * Map the models of the given project to the desired output files.
     *
     * @param project  The project whose urls should be generated.
     * @returns        A list of {@link UrlMapping} instances defining which models
     *                 should be rendered to which files.
     */
    getUrls(project) {
        const urls = [];
        urls.push(new UrlMapping_1.UrlMapping("index.html", project, this.indexTemplate));
        project.url = "index.html";
        project.anchor = undefined;
        project.hasOwnDocument = true;
        (project.children || []).forEach((child) => {
            DefaultTheme_1.DefaultTheme.applyAnchorUrl(child, project);
        });
        return urls;
    }
    /**
     * Triggered before a document will be rendered.
     *
     * @param page  An event object describing the current render operation.
     */
    onRendererBeginPage(page) {
        const model = page.model;
        if (!(model instanceof index_1.Reflection)) {
            return;
        }
        page.toc = new NavigationItem_1.NavigationItem();
        MinimalTheme.buildToc(page.model, page.toc);
    }
    /**
     * Create a toc navigation item structure.
     *
     * @param model   The models whose children should be written to the toc.
     * @param parent  The parent {@link Models.NavigationItem} the toc should be appended to.
     */
    static buildToc(model, parent) {
        const children = model.children || [];
        children.forEach((child) => {
            const item = NavigationItem_1.NavigationItem.create(child, parent, true);
            MinimalTheme.buildToc(child, item);
        });
    }
}
exports.MinimalTheme = MinimalTheme;
function bind(fn, first) {
    return (...r) => fn(first, ...r);
}
class MinimalThemeRendererContext extends DefaultThemeRenderContext_1.DefaultThemeRenderContext {
    constructor() {
        super(...arguments);
        this.indexTemplate = bind(templates_1.indexTemplate, this);
        this.defaultLayout = bind(default_1.defaultLayout, this);
        this.header = bind(header_1.header, this);
        this.member = bind(member_1.member, this);
    }
}
exports.MinimalThemeRendererContext = MinimalThemeRendererContext;
